==> calligra-2.4.3.tar.xz: calligra-2.4.3/stage/part/KPrPageData.cpp <==
/* This file is part of the KDE project
 * Copyright ( C ) 2007 Thorsten Zachmann <zachmann@kde.org>
 * Copyright (C) 2010 Benjamin Port <port.benjamin@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (  at your option ) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "KPrPageData.h"
#include "KPrShapeAnimations.h"

KPrPageData::KPrPageData()
{
}

KPrPageData::~KPrPageData()
{
    foreach (KPrAnimationStep *step, m_animations.steps()) {
        delete step;
    }
}

KPrShapeAnimations & KPrPageData::animations()
{
    return m_animations;
}

KPrPlaceholders & KPrPageData::placeholders()
{
    return m_placeholders;
}

const KPrPlaceholders & KPrPageData::placeholders() const
{
    return m_placeholders;
}

QList<KPrAnimationStep *> KPrPageData::animationSteps() const
{
    return m_animations.steps();
}

==> calligra_3.2.1+dfsg.orig.tar.xz: calligra-3.2.1/stage/part/KPrPageData.cpp <==
/* This file is part of the KDE project
 * Copyright ( C ) 2007 Thorsten Zachmann <zachmann@kde.org>
 * Copyright (C) 2010 Benjamin Port <port.benjamin@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (  at your option ) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "KPrPageData.h"
#include "KPrShapeAnimations.h"

KPrPageData::KPrPageData(KPrDocument *document)
    : m_animations(document)
{
}

KPrPageData::~KPrPageData()
{
    foreach (KPrAnimationStep *step, m_animations.steps()) {
        delete step;
    }
}

KPrShapeAnimations & KPrPageData::animations()
{
    return m_animations;
}

KPrPlaceholders & KPrPageData::placeholders()
{
    return m_placeholders;
}

const KPrPlaceholders & KPrPageData::placeholders() const
{
    return m_placeholders;
}

QList<KPrAnimationStep *> KPrPageData::animationSteps() const
{
    return m_animations.steps();
}
